@@ -384,6 +384,7 @@ providers_list = {
         r'mangajinnofansub\.com/lector/(series|read)/.',
     ],
     'mangakakalot_com': [
+        r'mangakakalot\.com/manga/.',
         r'mangakakalot\.com/read-.',
     ],
     'mangakatana_com': [
@@ -486,6 +487,9 @@ providers_list = {
     'manhuatai_com': [
         r'manhuatai\.com/.',
     ],
+    'manhwa18_net': [
+        r'manhwa18\.net/manga-.',
+    ],
     'merakiscans_com': [
         r'merakiscans\.com/manga/.',
     ],
